@@ -3,8 +3,9 @@ import pytest
 
 
 @pytest.mark.parametrize("backend", (
-    'classical',
-    'dwave',
+    'qcware/cpu',
+    'dwave/2000q',
+    'dwave/advantage',
 ))
 def test_solve_binary(backend):
     Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}
@@ -14,11 +15,16 @@ def test_solve_binary(backend):
             or result['solution'] == [1, 1, 1, 1])
 
 
-@pytest.mark.parametrize("backend", ('classical/simulator', ))
-def test_solve_binary_qaoa(backend):
+@pytest.mark.parametrize("backend,nmeasurement",
+                         [('qcware/cpu_simulator', None),
+                          ('awsbraket/sv1', 1000)])
+def test_solve_binary_qaoa(backend: str, nmeasurement: int):
     Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}
 
-    result = qcware.optimization.solve_binary(Q=Q, backend=backend)
+    result = qcware.optimization.solve_binary(Q=Q,
+                                              backend=backend,
+                                              qaoa_optimizer='analytical',
+                                              qaoa_nmeasurement=nmeasurement)
     assert (result['solution'] == [0, 0, 1, 1]
             or result['solution'] == [1, 1, 1, 1])
 
@@ -28,7 +34,7 @@ def test_solve_binary_qaoa(backend):
 def test_various_qaoa_optimizers(optimizer):
     Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}
     result = qcware.optimization.solve_binary(Q=Q,
-                                              backend='classical/simulator',
+                                              backend='qcware/cpu_simulator',
                                               qaoa_optimizer=optimizer)
     assert (result['solution'] == [0, 0, 1, 1]
             or result['solution'] == [1, 1, 1, 1])
@@ -43,9 +49,10 @@ def test_analytical_angles_with_qaoa():
     # print("ANGLES: ", angles)
 
     result = qcware.optimization.solve_binary(Q=Q,
-                                              backend='classical/simulator',
+                                              backend='qcware/cpu_simulator',
                                               qaoa_beta=angles[1][0],
                                               qaoa_gamma=angles[1][1],
                                               qaoa_p_val=1)
     assert (result['solution'] == [0, 0, 1, 1]
+            or result['solution'] == [1, 0, 1, 0]
             or result['solution'] == [1, 1, 1, 1])
